Exceptions
==========

Base exceptions
---------------

.. automodule:: vws.exceptions.base_exceptions
   :members:
   :show-inheritance:
   :inherited-members: Exception
   :exclude-members: errno, filename, filename2, strerror

VWS exceptions
--------------

.. automodule:: vws.exceptions.vws_exceptions
   :members:
   :show-inheritance:
   :inherited-members: Exception
   :exclude-members: errno, filename, filename2, strerror

CloudRecoService exceptions
---------------------------

.. automodule:: vws.exceptions.cloud_reco_exceptions
   :members:
   :show-inheritance:
   :inherited-members: Exception
   :exclude-members: errno, filename, filename2, strerror

Custom exceptions
-----------------

.. automodule:: vws.exceptions.custom_exceptions
   :members:
   :show-inheritance:
   :inherited-members: Exception
   :exclude-members: errno, filename, filename2, strerror
